==> ama_xiv_combat_sim-2024.6.7.1.tar.gz: ama_xiv_combat_sim-2024.6.7.1/ama_xiv_combat_sim/example_rotations/caster/rdm.py <==
from simulator.stats import Stats
from simulator.timeline_builders.rotation_builder import RotationBuilder


def get_rotation_RDM(skill_library):
    stats = Stats(
        wd=132,
        weapon_delay=3.44,
        main_stat=3379,
        det_stat=1601,
        crit_stat=2514,
        dh_stat=1708,
        speed_stat=502,
        job_class="RDM",
        healer_or_caster_strength=214,
        version="6.55",
    )
    rotation_name = "RDM 6.55"

    rb = RotationBuilder(
        stats,
        skill_library,
        enable_autos=True,
        ignore_trailing_dots=True,
        snap_dots_to_server_tick_starting_at=0,
    )
    rb.add_next("Verthunder III")
    rb.add_next("Veraero III")
    rb.add_next("Swiftcast")
    rb.add_next("Acceleration")
    rb.add_next("Verthunder III")
    rb.add_next("Grade 8 Tincture")
    rb.add_next("Verthunder III")
    rb.add_next("Embolden")
    rb.add_next("Manafication")
    rb.add_next("Enchanted Riposte")
    rb.add_next("Fleche")
    rb.add_next("Enchanted Zwerchhau")
    rb.add_next("Contre Sixte")
    rb.add_next("Enchanted Redoublement")
    rb.add_next("Corps-a-corps")
    rb.add_next("Engagement")
    rb.add_next("Verholy")
    rb.add_next("Corps-a-corps")
    rb.add_next("Engagement")
    rb.add_next("Scorch")
    rb.add_next("Resolution")
    rb.add_next("Verfire")
    rb.add_next("Verthunder III")
    rb.add_next("Verstone")
    rb.add_next("Veraero III")
    rb.add_next("Jolt II")
    rb.add_next("Verthunder III")
    rb.add_next("Fleche")
    return (rotation_name, rb)

==> ama_xiv_combat_sim-2024.6.11.3.tar.gz: ama_xiv_combat_sim-2024.6.11.3/ama_xiv_combat_sim/example_rotations/caster/rdm.py <==
from ama_xiv_combat_sim.simulator.stats import Stats
from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import RotationBuilder


def get_rotation_RDM(skill_library):
    stats = Stats(
        wd=132,
        weapon_delay=3.44,
        main_stat=3379,
        det_stat=1601,
        crit_stat=2514,
        dh_stat=1708,
        speed_stat=502,
        job_class="RDM",
        healer_or_caster_strength=214,
        version="6.55",
    )
    rotation_name = "RDM 6.55"

    rb = RotationBuilder(
        stats,
        skill_library,
        enable_autos=True,
        ignore_trailing_dots=True,
        snap_dots_to_server_tick_starting_at=0,
    )
    rb.add_next("Verthunder III")
    rb.add_next("Veraero III")
    rb.add_next("Swiftcast")
    rb.add_next("Acceleration")
    rb.add_next("Verthunder III")
    rb.add_next("Grade 8 Tincture")
    rb.add_next("Verthunder III")
    rb.add_next("Embolden")
    rb.add_next("Manafication")
    rb.add_next("Enchanted Riposte")
    rb.add_next("Fleche")
    rb.add_next("Enchanted Zwerchhau")
    rb.add_next("Contre Sixte")
    rb.add_next("Enchanted Redoublement")
    rb.add_next("Corps-a-corps")
    rb.add_next("Engagement")
    rb.add_next("Verholy")
    rb.add_next("Corps-a-corps")
    rb.add_next("Engagement")
    rb.add_next("Scorch")
    rb.add_next("Resolution")
    rb.add_next("Verfire")
    rb.add_next("Verthunder III")
    rb.add_next("Verstone")
    rb.add_next("Veraero III")
    rb.add_next("Jolt II")
    rb.add_next("Verthunder III")
    rb.add_next("Fleche")
    return (rotation_name, rb)
